import unittest
import apc
import matplotlib.pyplot as plt

class TestPlotFit(unittest.TestCase):

    def test_TA(self):
        model = apc.Model()
        model.data_from_df(apc.loss_TA(), data_format='CL')
        model.fit('od_poisson_response', 'Ad')
        model.plot_fit()
        for style in ('detrend', 'sum_sum'):
            model.plot_fit(style)
        plt.close('all')
        for sr in ('start', 'mean', 'end', False):
            model.plot_fit(simplify_ranges=sr)
        plt.close('all')
        model.plot_fit(around_coef=False)
        
    def test_asbestos(self):
        model = apc.Model()
        model.data_from_df(apc.asbestos(), data_format='PA')
        model.fit('poisson_response', 'AC')
        model.plot_fit()
        for style in ('detrend', 'sum_sum'):
            model.plot_fit(style)
        plt.close('all')
        for sr in ('start', 'mean', 'end', False):
            model.plot_fit(simplify_ranges=sr)
        plt.close('all')
        model.plot_fit(around_coef=False)
        
    def test_Belgian(self):
        model = apc.Model()
        model.data_from_df(**apc.Belgian_lung_cancer())
        model.fit('log_normal_rates', 'APC')
        model.plot_fit()
        for style in ('detrend', 'sum_sum'):
            model.plot_fit(style)
        plt.close('all')
        for sr in ('start', 'mean', 'end', False):
            model.plot_fit(simplify_ranges=sr)
        plt.close('all')
        model.plot_fit(around_coef=False)
        
if __name__ == '__main__':
    unittest.main()


import unittest
import pandas as pd
import apc
from pkg_resources import resource_filename

class TestDataFromDf(unittest.TestCase):

    def test_asbestos(self):
        model = apc.Model()
        model.data_from_df(apc.asbestos())
        
        self.assertEqual(model.data_format, 'PA')
        self.assertEqual(model.I, 70)
        self.assertEqual(model.J, 41)
        self.assertEqual(model.K, 110)
        self.assertEqual(model.L, 69)
        self.assertEqual(model.n, 2870)
        self.assertEqual(model.data_vector.sum()['response'], 32164)    
    
    def test_TA(self):
        model = apc.Model()
        model.data_from_df(apc.loss_TA())
        
        self.assertEqual(model.data_format, 'CA')
        self.assertEqual(model.I, 10)
        self.assertEqual(model.J, 10)
        self.assertEqual(model.K, 10)
        self.assertEqual(model.L, 0)
        self.assertEqual(model.n, 55)
        self.assertEqual(model.time_adjust, 1)
        self.assertEqual(round(model.data_vector.sum()['response'],3), 
                         34358090.0)

    def test_BZ(self):
        model = apc.Model()
        model.data_from_df(apc.loss_BZ(), data_format='CL')
        
        self.assertEqual(model.data_format, 'CL')
        self.assertEqual(model.I, 11)
        self.assertEqual(model.J, 11)
        self.assertEqual(model.K, 11)
        self.assertEqual(model.L, 0)
        self.assertEqual(model.n, 66)
        self.assertEqual(model.time_adjust, 0)
        self.assertEqual(round(model.data_vector.sum()['response'],3), 
                         10221194.0)        
        
    def test_Belgian(self):
        data = pd.read_excel(
            resource_filename('apc', 'data/Belgian_lung_cancer.xlsx'), 
            sheet_name = ['response', 'rates'], 
            index_col = 0)
        model = apc.Model()
        model.data_from_df(data['response'], rate=data['rates'], 
                           data_format='AP')
        
        self.assertEqual(model.data_format, 'AP')
        self.assertEqual(model.I, 11)
        self.assertEqual(model.J, 4)
        self.assertEqual(model.K, 14)
        self.assertEqual(model.L, 10)
        self.assertEqual(model.n, 44)
        self.assertEqual(round(model.data_vector.sum()['response'],3), 
                         6092.0)
        self.assertEqual(round(model.data_vector.sum()['dose'],3), 
                         590.843)
        self.assertEqual(round(model.data_vector.sum()['rate'],3),
                         553.150)
    
if __name__ == '__main__':
    unittest.main()


import unittest
import apc

class TestRTest(unittest.TestCase):

    def test_VNJ(self):
        r = apc.r_test(apc.loss_VNJ(), 
                       'gen_log_normal_response', 'AC')
        self.assertEqual(round(r['R_stat'],3), 113.185)
        self.assertEqual(round(r['p_value'],5), 0.00114)
        self.assertEqual(round(r['power_at_R'],5), 0.82657)

    def test_BZ(self):
        r = apc.r_test(apc.loss_BZ(), 
                       'gen_log_normal_response', 'APC', 
                       R_stat='ls', R_dist='wls_ql',
                       data_format='CL')
        self.assertEqual(round(r['R_stat'],5), 113.92399)
        self.assertEqual(round(r['p_value'],5), 0.01754)
        self.assertEqual(round(r['power_at_R'],5), 0.86713)
        
    def test_TA(self):
        r = apc.r_test(apc.loss_TA(),
                       'od_poisson_response', 'Ad', 
                       R_stat='ql', R_dist='ls',
                       data_format='CL')
        self.assertEqual(round(r['R_stat'],5), 73.16521)
        self.assertEqual(round(r['p_value'],5), 0.78526)
        self.assertEqual(round(r['power_at_R'],5), 0.99896)
        
if __name__ == '__main__':
    unittest.main()


"""apc: Age-Period-Cohort and extended Chain-Ladder Analysis."""

import setuptools

with open("README.md", "r", encoding='utf8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='apc',
    version='1.0.1',
    description='Age-Period-Cohort and extended Chain-Ladder Analysis',
    url='http://github.com/JonasHarnau/apc',
    author='Jonas Harnau',
    author_email='j.harnau@outlook.com',
    license='GPLv3',
    packages=setuptools.find_packages(),
    python_requires='>=3.6',
    install_requires=[
        'matplotlib', 'numpy', 'pandas', 'quad_form_ratio', 'seaborn',
        'scipy', 'statsmodels'
    ],
    include_package_data=True,
    classifiers=['Development Status :: 3 - Alpha'],
    long_description=long_description,
    long_description_content_type="text/markdown",
    zip_safe=False)



import unittest
import apc
import matplotlib.pyplot as plt

class TestPlotDataSums(unittest.TestCase):

    def test_TA(self):
        model = apc.Model()
        model.data_from_df(apc.loss_TA(), data_format='CL')
        model.plot_data_sums()
        model.plot_data_sums(logy=True)
        for simplify_ranges in ('start', 'mean', 'end', False):
            model.plot_data_sums(simplify_ranges)
        plt.close('all')

    def test_Belgian(self):
        model = apc.Model()
        model.data_from_df(**apc.Belgian_lung_cancer())
        model.plot_data_sums()
        model.plot_data_sums(logy=True)
        for simplify_ranges in ('start', 'mean', 'end', False):
            model.plot_data_sums(simplify_ranges)
        plt.close('all')

if __name__ == '__main__':
    unittest.main()


import unittest
import numpy as np
import apc

class TestIdentify(unittest.TestCase):

    def test_BZ_ln(self):
        model = apc.Model()
        model.data_from_df(apc.loss_BZ())
        model.fit('log_normal_response', 'APC')
        model.identify()

        self.assertTrue(
            np.allclose(
            model.parameters_adhoc.sum().values,
            np.array(
                [11.52208551,   1.92807476, 309.55066566,  16.5398655]
            )
            )
        )
        self.assertTrue(
            np.allclose(
            model.identify('sum_sum', attach_to_self=False).sum().values,
            np.array(
                [-17.03573805,   5.27028714,  18.73830563,  19.19957677]
            )
            )
        )
    
    def test_TA_odp(self):
        model = apc.Model()
        model.data_from_df(apc.loss_TA(), data_format='CL')
        model.fit('od_poisson_response', 'AC')
        model.identify()

        self.assertTrue(
            np.allclose(
            model.parameters_adhoc.sum().values,
            np.array(
                [19.93493555, 12.35339911, 23.27262888, 12.98041616]
            )
            )
        )
        self.assertTrue(
            np.allclose(
            model.identify('sum_sum', attach_to_self=False).sum().values,
            np.array(
                [-40.35513352,  19.04311385, -62.3882387 ,   8.99524907]
            )
            )
        )

    def test_Belgian_gauss_rates(self):
        model = apc.Model()
        model.data_from_df(**apc.Belgian_lung_cancer())
        predictors = ['APC', 'AP', 'AC', 'PC', 'Ad', 'Pd', 'Cd',
                      'A', 'P', 'C', 't', 'tA', 'tP', 'tC', '1']
        for p in predictors:
            model.fit('gaussian_rates', p)
            model.identify('sum_sum')
            model.identify('detrend')

    def test_Belgian_bin_dose_response(self):
        data = apc.Belgian_lung_cancer()
        dose = (data['response']/data['rate'] * 10**5).astype(int)
        model = apc.Model()
        model.data_from_df(data['response'], dose=dose, data_format='AP')
        model.fit('binomial_dose_response', 'A')
        model.identify()

        self.assertTrue(
            np.allclose(
            model.parameters_adhoc.sum().values,
            np.array(
                [-6.56083837,  3.05256213, 18.37617231,  3.71767601]
            )
            )
        )
        self.assertTrue(
            np.allclose(
            model.identify('sum_sum', attach_to_self=False).sum().values,
            np.array(
                [-14.19804504,    3.52539429, -220.13119605,    5.58065264]
            )
            )
        )
        
if __name__ == '__main__':
    unittest.main()